using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using MonoTouch.AVFoundation;

namespace ScanBarCodes
{
	public class ImageLoadedEventArgs : EventArgs
	{
		UIImage _img;
	

		public UIImage Image
		{
			get
			{
				return _img;
			}
		}

		public ImageLoadedEventArgs(UIImage image)
		{
			_img = image;		
		}
	}

	public class CoverUrlConnectionDelegate : NSUrlConnectionDelegate
	{
		#region Private Members
		NSMutableData _responseData;
		string _isbn;
		NSUrl _url;
		#endregion

		#region Properties
		public string ISBN
		{
			get{
				return _isbn;
			}
		}
		public NSUrl Url
		{
			get{
				return _url;
			}
		}
	
		#endregion 

		#region Events
		public delegate void ImageLoadedHandler(object sender, ImageLoadedEventArgs args);

		public event ImageLoadedHandler ImageLoaded;

		void OnImageLoaded (UIImage img)
		{
			if (ImageLoaded != null)
				ImageLoaded (this, new ImageLoadedEventArgs (img));
		}

		public delegate void ImageLoadFailedHander (object sender, ImageLoadedEventArgs args);

		public event ImageLoadFailedHander ImageLoadFailed;

		void OnImageLoadFailed()
		{
			if (ImageLoadFailed != null)
				ImageLoadFailed (this, new ImageLoadedEventArgs (null));
		}
		#endregion

		public CoverUrlConnectionDelegate(string isbn)
		{
			_isbn = isbn;
		}

		public override void ReceivedResponse (NSUrlConnection connection, NSUrlResponse response)
		{
			_responseData = new NSMutableData ();
		}

		public override void ReceivedData (NSUrlConnection connection, NSData data)
		{
			_responseData.AppendData (data);
		}

		public override NSCachedUrlResponse WillCacheResponse (NSUrlConnection connection, NSCachedUrlResponse cachedResponse)
		{
			return null;
		}

		public override void FinishedLoading (NSUrlConnection connection)
		{
			this._url =	connection.CurrentRequest.Url;
			UIImage img = new UIImage (_responseData);
			this.OnImageLoaded (img);
		}

		public override void FailedWithError (NSUrlConnection connection, NSError error)
		{
			this.OnImageLoadFailed ();
		}
	}
}