using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using MonoTouch.AVFoundation;

namespace ScanBarCodes
{


	public class SimpleCaptureMetadataOutputObjectsDelegate : AVCaptureMetadataOutputObjectsDelegate
	{
		#region Private Members
		ScanBarCodesViewController _parentViewController;
		#endregion
		
		#region ctor
		public SimpleCaptureMetadataOutputObjectsDelegate(ScanBarCodesViewController parent)
		{
			_parentViewController = parent;
		}
		#endregion

		#region Events
		public delegate void ISBNDetectedHandler(object sender, ISBNDetectedEventArgs args);

		public event ISBNDetectedHandler ISBNDetected;

		void OnISBNDetected (string id, RectangleF frame)
		{
			if (ISBNDetected != null)
				ISBNDetected (this, new ISBNDetectedEventArgs (id,frame, true));
		}

		public delegate void ISBNUndetectedHandler (object sender, ISBNDetectedEventArgs args);

		public event ISBNUndetectedHandler ISBNUndetected;

		void OnISBNUndetected()
		{
			if (ISBNUndetected != null)
				ISBNUndetected (this, new ISBNDetectedEventArgs(null,RectangleF.Empty, false));
		}
		#endregion 

		public override void DidOutputMetadataObjects (AVCaptureMetadataOutput captureOutput, AVMetadataObject[] metadataObjects, AVCaptureConnection connection)
		{
			RectangleF highlightViewRect = RectangleF.Empty;
			AVMetadataMachineReadableCodeObject barCodeObject;
			string detectionString = null;

			string[] barCodeTypes =  {
				AVMetadataObject.TypeUPCECode.ToString(),
				AVMetadataObject.TypeCode39Code.ToString(),
				AVMetadataObject.TypeCode39Mod43Code.ToString(),
				AVMetadataObject.TypeEAN13Code.ToString(),
				AVMetadataObject.TypeEAN8Code.ToString(),
				AVMetadataObject.TypeCode93Code.ToString(),
				AVMetadataObject.TypeCode128Code.ToString(),
				AVMetadataObject.TypePDF417Code.ToString(),
				AVMetadataObject.TypeQRCode.ToString(),
				AVMetadataObject.TypeAztecCode.ToString()
			};

			foreach (AVMetadataObject metadata in metadataObjects) {
				foreach (NSString type in barCodeTypes) {
					if ( metadata.Type.ToString() == type)
					{
						barCodeObject = (AVMetadataMachineReadableCodeObject)_parentViewController.PreviousLayer.GetTransformedMetadataObject ((AVMetadataMachineReadableCodeObject)metadata);
						highlightViewRect = barCodeObject.Bounds;
						detectionString = ((AVMetadataMachineReadableCodeObject)metadata).StringValue;
						break;
					}
				}

				if (detectionString != null)
				{
					this.OnISBNDetected (detectionString, highlightViewRect);
					break;
				}
				else
				{
					OnISBNUndetected();
				}
			}
		}
	}
}

